from setuptools import setup

setup(name='dgdR-distributions',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['dgdR_distributions'],
      author='Raghu Kula',
      author_email='raghuvarankula@gmail.com',
      zip_safe=False)
